@@ -1,6 +1,6 @@
 //! Compressed Sparse Row (CSR) is a sparse adjacency matrix graph.
 
-use std::cmp::max;
+use std::cmp::{max, Ordering};
 use std::iter::{Enumerate, Zip};
 use std::marker::PhantomData;
 use std::ops::{Index, IndexMut, Range};
@@ -162,8 +162,9 @@ where
     {
         let max_node_id = match edges
             .iter()
-            .map(|edge| match edge.clone().into_weighted_edge() {
-                (x, y, _) => max(x.index(), y.index()),
+            .map(|edge| {
+                let (x, y, _) = edge.clone().into_weighted_edge();
+                max(x.index(), y.index())
             })
             .max()
         {
@@ -316,10 +317,10 @@ where
         let (index, neighbors) = self.neighbors_of(a);
         if neighbors.len() < BINARY_SEARCH_CUTOFF {
             for (i, elt) in neighbors.iter().enumerate() {
-                if b == *elt {
-                    return Ok(i + index);
-                } else if *elt > b {
-                    return Err(i + index);
+                match elt.cmp(&b) {
+                    Ordering::Equal => return Ok(i + index),
+                    Ordering::Greater => return Err(i + index),
+                    Ordering::Less => {}
                 }
             }
             Err(neighbors.len() + index)
